<?php

namespace Drupal\sass_compile\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class SassCompileConfigForm.
 */
class SassCompileConfigForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'sass_compile.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'sass_compile_config_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('sass_compile.settings');
    $form['sass_files_folder'] = [
      '#type' => 'textfield',
      '#title' => $this->t('SASS files location'),
      '#description' => $this->t('Sass files folder path. Ex. themes/themeName/sass'),
      '#default_value' => $config->get('sass_files_folder'),
    ];
    $form['css_files_folder'] = [
      '#type' => 'textfield',
      '#title' => $this->t('CSS files save location'),
      '#description' => $this->t('CSS files save folder path. Ex. themes/themeName/css'),
      '#default_value' => $config->get('css_files_folder'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);
    $this->config('sass_compile.settings')
      ->set('sass_files_folder', $form_state->getValue('sass_files_folder'))
      ->set('css_files_folder', $form_state->getValue('css_files_folder'))
      ->save();
    if($form_state->getValue('sass_files_folder') && $form_state->getValue('css_files_folder')) {
      $messenger = \Drupal::messenger();
      $source = $form_state->getValue('sass_files_folder');
      $destination = $form_state->getValue('css_files_folder');
      \Drupal::service('sass_compile.sass_compile')->compileScssFiles($source, $destination);
      $messenger->addMessage("Compilation completed. Please refer log for more information.");
    }
  }
}
